Activities — Stisla

# Activities

## September 2018

2 min ago View

Have commented on the task of "Responsive design".

1 hour ago View

Moved the task "Fix some features that are bugs in the master module" from Progress to Finish.

4 hour ago View

Login to the system with ujang@maman.com email and location in Bogor.

12 hour ago View

Log out of the system after 6 hours using the system.

Yesterday View

Removing task "Delete all unwanted selectors in CSS files".

Yesterday View

Assign the task of "Redesigning website header and make it responsive AF" to Syahdan Ubaidilah.